============
Octavia User
============

Cookbooks
=========
.. toctree::
   :glob:
   :maxdepth: 1

   guides/basic-cookbook
   guides/l7-cookbook

Guides
======
.. toctree::
   :glob:
   :maxdepth: 1

   guides/l7
   feature-classification/index

References
==========
.. toctree::
   :glob:
   :maxdepth: 1

   Octavia API Reference <https://docs.openstack.org/api-ref/load-balancer/>
   Command Line Interface Reference <https://docs.openstack.org/python-octaviaclient/latest/cli/index.html>
   sdks

Videos
======
.. toctree::
   :glob:
   :maxdepth: 1

   Introduction to OpenStack Load Balancing (2017 Boston Summit) <https://youtu.be/BBgP3_qhJ00>

.. only:: html

   Indices and Search
   ------------------

   * :ref:`genindex`
   * :ref:`search`
